@@ -9,6 +9,7 @@ from .destination_3TLIPFS.client import Destination3TLIPFS
 from .source_3TLIPFS.client import Source3TLIPFS
 from .source_postgres.client import PostgresSource
 from .destination_postgres.client import PostgresDestination
+from .source_exchange_rates.source import SourceExchangeRates
 
 __all__ = [
     'files',
@@ -22,5 +23,6 @@ __all__ = [
     'Source3TLIPFS',
     'PostgresDestination',
     'PostgresSource'
+    'SourceExchangeRates'
 
 ]
