@@ -1,8 +1,6 @@
 
 import os
 import requests
-import sys
-import json
 from enum import Enum
 from airbyte_cdk.models import AirbyteConnectionStatus,Status
 
@@ -14,15 +12,13 @@ class IPFSSource:
 
         Configuration parameters in json format:
         - IPFSURL (string): link to fetch data from ipfs source.
-              
+        kindly add it as string 
     """
 
     def __init__(self, config: dict, clientSelf):
         self.IPFSURL = config["IPFSURL"]
         self.clientSelf = clientSelf
        
-     
-
 
     def check(self)-> AirbyteConnectionStatus:
         """
@@ -30,9 +26,9 @@ class IPFSSource:
         It attempts to connect to the IPFS url provided by user  and prints a success message if successful.
         """
         try:
-           
+            
             f = requests.get(self.IPFSURL)
-            if f.ok :
+            if f.status_code == 200 :
                 self.clientSelf.logInfo(self.clientSelf.step, 'IPFS  connection successful')
                 return AirbyteConnectionStatus(status=Status.SUCCEEDED)
             else :
@@ -48,11 +44,11 @@ class IPFSSource:
     def read(self):
         """
         Read content and store it at temperory location.
-        
         """
         try:
+
             streamData = requests.get(self.IPFSURL)
-            if streamData.ok :
+            if streamData.status_code == 200 :
                 self.clientSelf.logInfo(self.clientSelf.step, ' Read Data successful')
                 return  streamData
             else :
@@ -62,5 +58,4 @@ class IPFSSource:
             self.clientSelf.logError(self.clientSelf.step, f"Failed to fetch the data: {str(e)}")
 
 
-        
         
\ No newline at end of file
